@@ -3,7 +3,7 @@ if numexpr.__version__ < 2.0:
     raise ImportError('Please update numexpr to a newer version > 2.0.')
 
 import numpy as np
-from .decorators import real, square, idempotent, inplace, universal
+from .decorators import real, square, idempotent, inplace, separable
 from .core import (Operator, BlockColumnOperator, CompositionOperator,
                    IdentityOperator, ReductionOperator)
 from .utils import operation_assignment, operation_symbol, strenum
@@ -23,7 +23,7 @@ __all__ = ['ClipOperator',
 
 @square
 @inplace
-@universal
+@separable
 class ClipOperator(Operator):
     """
     Clip (limit) the values in an array.
@@ -113,7 +113,7 @@ class MaxOperator(ReductionOperator):
 
     """
     def __init__(self, axis=None, dtype=None, skipna=False, **keywords):
-        if np.__version__ < '1.7':
+        if np.__version__ < '1.8':
             func = np.nanmax if skipna else np.max
         else:
             func = np.max
@@ -146,7 +146,7 @@ class MinOperator(ReductionOperator):
 
     """
     def __init__(self, axis=None, dtype=None, skipna=False, **keywords):
-        if np.__version__ < '1.7':
+        if np.__version__ < '1.8':
             func = np.nanmin if skipna else np.min
         else:
             func = np.min
@@ -194,7 +194,7 @@ class MinMaxOperator(BlockColumnOperator):
 
 @square
 @inplace
-@universal
+@separable
 class MaximumOperator(Operator):
     """
     Set all input array values above a given value to this value.
@@ -224,7 +224,7 @@ class MaximumOperator(Operator):
 
 @square 
 @inplace
-@universal
+@separable
 class MinimumOperator(Operator):
     """
     Set all input array values above a given value to this value.
@@ -252,7 +252,6 @@ class MinimumOperator(Operator):
         Operator.__init__(self, lambda i,o: np.minimum(i, value, o), **keywords)
 
 
-# numexpr 2.0 cannot handle inplace reductions
 @square
 @inplace
 class NumexprOperator(Operator):
@@ -279,8 +278,10 @@ class NumexprOperator(Operator):
     def __init__(self, expr, global_dict=None, dtype=float, **keywords):
         self.expr = expr
         self.global_dict = global_dict
-        Operator.__init__(self, dtype=dtype, flags={'inplace_reduction':False},
-                          **keywords)
+        if numexpr.__version__ < '2.0.2':
+            keywords['flags'] = self.validate_flags(keywords.get('flags', {}),
+                                                    inplace_reduction=False)
+        Operator.__init__(self, dtype=dtype, **keywords)
 
     def direct(self, input, output, operation=operation_assignment):
         if operation is operation_assignment:
@@ -294,7 +295,7 @@ class NumexprOperator(Operator):
 @square
 @idempotent
 @inplace
-@universal
+@separable
 class RoundOperator(Operator):
     """Rounding operator.
     
@@ -350,7 +351,7 @@ class RoundOperator(Operator):
 @square
 @idempotent
 @inplace
-@universal
+@separable
 class HardThresholdingOperator(Operator):
     """
     Hard thresholding operator.
@@ -389,7 +390,7 @@ class HardThresholdingOperator(Operator):
 @real
 @square
 @inplace
-@universal
+@separable
 class SoftThresholdingOperator(Operator):
     """
     Soft thresholding operator.
