@@ -10,6 +10,7 @@ __all__ = ['assert_eq',
            'assert_is_not_instance',
            'assert_is_none',
            'assert_is_not_none',
+           'assert_raises',
            'skiptest']
 
 def assert_eq(a, b, msg=None):
@@ -70,28 +71,14 @@ def assert_raises(*args, **kwargs):
     np.testing.assert_raises(*args, **kwargs)
 assert_raises.__doc__ = np.testing.assert_raises.__doc__
 
-def assert_raises_if(condition, *args, **kwargs):
-    """
-    assert_raises_if(condition, exception_class, callable, *args, **kwargs)
-
-    Fail if condition is true unless an exception of class exception_class is
-    thrown by the callable. If the condition is not true, the callable is still
-    called.
-    """
-    try:
-        np.testing.assert_raises(*args, **kwargs)
-    except AssertionError:
-        if condition:
-            raise
-
-def _get_msg(msg):
-    if not msg:
-        return '.'
-    return ': ' + str(msg) + '.'
-
 def skiptest(func):
     from nose.plugins.skip import SkipTest
     def _():
         raise SkipTest()
     _.__name__ = func.__name__
     return _
+
+def _get_msg(msg):
+    if not msg:
+        return '.'
+    return ': ' + str(msg) + '.'
